# Some Rcmdr dialogs for the TeachingDemos package

# last modified: 2015-12-08 by J. Fox

# Note: the following function (with contributions from Richard Heiberger and Milan Bouchet-Valat) 
# can be included in any Rcmdr plug-in package to cause the package to load
# the Rcmdr if it is not already loaded

.onAttach <- function(libname, pkgname){
    if (!interactive()) return()
    putRcmdr("slider.env", new.env())    
    Rcmdr <- options()$Rcmdr
    plugins <- Rcmdr$plugins
    if (!pkgname %in% plugins) {
        Rcmdr$plugins <- c(plugins, pkgname)
        options(Rcmdr=Rcmdr)
        if("package:Rcmdr" %in% search()) {
            if(!getRcmdr("autoRestart")) {
                closeCommander(ask=FALSE, ask.save=TRUE)
                Commander()
            }
        }
        else {
            Commander()
        }
    }
}

# Data menu

DisplayObjects <- function(){
  command <- paste("ls(", ")", sep="")
  doItAndPrint(command)
}

RemoveDatasets <- function(){
  dataSets <- listDataSets()
  .activeDataSet <- ActiveDataSet()
  if ((length(dataSets) == 1) && !is.null(.activeDataSet)) {
    Message(message=gettextRcmdr("There is only one dataset in memory."),
            type="warning")
    tkfocus(CommanderWindow())
    return()
  }
  if (length(dataSets) == 0){
    Message(message=gettextRcmdr("There are no data sets in the workspace"),
            type="error")
    tkfocus(CommanderWindow())
    return()
  }
  initializeDialog(title=gettextRcmdr("Remove Datasets"))
  dataSetsBox <- variableListBox(top, dataSets, title=gettextRcmdr("Datasets (pick one or more)"),
                                selectmode="multiple")
  onOK <- function(){
    selection <- getSelection(dataSetsBox)
    closeDialog()
    if (length(selection) == 0){
      errorCondition(recall=RemoveDatasets, message=gettextRcmdr("You must select at least one dataset."))
      return()
    }
    command <- paste("rm(", selection, ")", sep="")
    doItAndPrint(command)
    Message(paste(gettextRcmdr("Datasets removed:"), paste(selection, collapse=", "), 
      " / ", "When the active dataset is removed, 'Exit > Restart the Commander' is recommended."), type="note")
  }
  OKCancelHelp(helpSubject="rm")
  tkgrid(getFrame(dataSetsBox), sticky="nw")
  tkgrid(buttonsFrame, sticky="w")
  dialogSuffix()
}

DisplayRowNames <- function(){
  dataSets <- listDataSets()
  .activeDataSet <- ActiveDataSet()
  if (length(dataSets) == 0){
    Message(message=gettextRcmdr("There are no data sets in the workspace"),
            type="error")
    tkfocus(CommanderWindow())
    return()
  }
  initializeDialog(title=gettextRcmdr("Display Rownames"))
  dataSetsBox <- variableListBox(top, dataSets, title=gettextRcmdr("Dataset (pick one)"),
                                 selectmode="single")
  onOK <- function(){
    selection <- getSelection(dataSetsBox)
    closeDialog()
    if (length(selection) == 0){
      errorCondition(recall=Display, message=gettextRcmdr("You must select at least one dataset."))
      return()
    }
    command <- paste("row.names(", selection, ")", sep="")
    doItAndPrint(command)
    Message(paste(gettextRcmdr("Dataset "), selection, "'s rownames are displayed", sep=""), type="note")
  }
  OKCancelHelp(helpSubject="row.names")
  tkgrid(getFrame(dataSetsBox), sticky="nw")
  tkgrid(buttonsFrame, sticky="w")
  dialogSuffix()
}

# Statistics menu

DisplayStructure <- function(){
  .activeDataSet <- activeDataSet()
  command <- paste("str(", .activeDataSet, ")", sep="")
  doItAndPrint(command)
}

TukeyFiveNumber <- function(){
  initializeDialog(title=gettextRcmdr("Tukey's Five Number Summary"))
  xBox <- variableListBox(top, Numeric(), title=gettextRcmdr("Variable (pick one)"),
                          selectmode="single")
  onOK <- function(){
    variable <- getSelection(xBox)
    closeDialog(top)
    if (length(variable) == 0){
      errorCondition(recall=TukeyFiveNumber, message=gettextRcmdr("You must select one package."))
      return()
    }
    .activeDataSet <- activeDataSet()
    command <- paste("fivenum(", .activeDataSet, "$", variable, ")", sep="")
    doItAndPrint(command)
  }
  OKCancelHelp(helpSubject="fivenum")
  tkgrid(getFrame(xBox), sticky="nw")
  tkgrid(buttonsFrame, sticky="w")
  dialogSuffix()
}

# Models menu

RemoveModels <- function(){
  models <- listAllModels()
  .activeModel <- ActiveModel()
  if ((length(models) == 1) && !is.null(.activeModel)) {
    Message(message=gettextRcmdr("There is only one model in memory."),
            type="warning")
    tkfocus(CommanderWindow())
    return()
  }
  if (length(models) == 0){
    Message(message=gettextRcmdr("There are no models sets in the workspace"),
            type="error")
    tkfocus(CommanderWindow())
    return()
  }
  initializeDialog(title=gettextRcmdr("Remove Models"))
  modelsBox <- variableListBox(top, models, title=gettextRcmdr("Models (pick one or more)"),
                                 selectmode="multiple")
  onOK <- function(){
    selection <- getSelection(modelsBox)
    closeDialog()
    if (length(selection) == 0){
      errorCondition(recall=RemoveModels, message=gettextRcmdr("You must select at least one model."))
      return()
    }
    command <- paste("rm(", selection, ")", sep="")
    doItAndPrint(command)
    Message(paste(gettextRcmdr("Models removed:"), paste(selection, collapse=", ")), type="note")
  }
  OKCancelHelp(helpSubject="rm")
  tkgrid(getFrame(modelsBox), sticky="nw")
  tkgrid(buttonsFrame, sticky="w")
  dialogSuffix()
}


# Help menu
BrowseR2bitWebsite <- function() browseURL("https://r2bit.com/")
BrowseRcmdrkrBlog <- function() browseURL("https://rcmdr.kr/")
